//-----------------------------------------------------------
//          AbilityLimitBreak                                <br />
//                                                           <br />
//          RPG Ability "Limit break"                        <br />
//          Ability that gives pawn a limit break upon
//          reaching x # of limit points.                    <br />
//          <b>NOTE!!</b> <i>The limit points are set to 0
//          each map they do not carry over from map to map.
//                                                           <br />
//
//          Author: Continuum                                <br />
//
//-----------------------------------------------------------
class AbilityLimitBreak extends RPGAbility config(UT2004RPG) abstract;









/**
   Returns a name for this ability <br />
   <strike>Should</strike> <b>Must</b> be unique
   and sub-classes must override.
*/
static function string abilityName()
{
       return "AbilityLimitBreak";
}

/**
   While isLimit give pawn the limit break for pawns abilityLvl.

*/
static function ModifyPawn(Pawn p, int abilityLvl)
{
  local float initialRate;
  local float timerStart;
  local float time;
  local LimitBreakUtil lbUtil;
  local LimitBreakInv lbInv;



  local Inventory inv;
  inv = p.FindInventoryType(class'LimitBreakInv');

  /*
  if(inv.Class == lbInv.Class)
  {
   lbInv = inv;
  }
  */
  lbUtil = lbInv.lbUtil;






  /*
    Bad spot for the following code... need a 2nd Inventory that actuall
    gives the pawn the ability (probably that inventory will contain the
    LimitBreakInv object)
  */

  time=0.00;
  initialrate = p.TimerRate;
  p.SetTimer(0.99, true);

  timerStart = p.TimerCounter;


  //Do a limit break until timer runs out (5 seconds)
  while(time < (timerStart + lbUtil.breakLength))
  {
    time = p.TimerCounter;

  }





}//ModifyPawn()


/**
    Award limit points on taking damage.  <br />
    Ignore if self-damage.<br /><br />
    <b>Note</b><br />
    <i>LimitBreakUtil stores and calculates a lot of the variables used in this
    ability.</i>
*/
static function HandleDamage(out int Damage, Pawn Injured, Pawn Instigator, out vector Momentum, class<DamageType> DamageType, bool bOwnedByInstigator, int AbilityLevel)
{
    local int playerLvl;
    local LimitBreakUtil lbUtil;
    local LimitBreakInv lbInv;
    local int abilityLvl;


    playerLvl = 0;
    //quik escape process nothing more
    if(bOwnedByInstigator || Damage <= 0 || (Injured.Health - Damage) <= 0)
		return; //if the instigator is doing the damage, damage is nothing or pawn gets killed, ignore this.

    /*
      ok to proceed no self damage, damage has bean dealt,
      and pawn isn't killed by damage. Create local variables
      and add limitPoints
      <br />
      need call super.HandlDamage() to inflict the damage?

    */

    lbUtil.calcHealthFactor(Injured.Health, Injured.SuperHealthMax);//pass pawns health and max health to the limit break utility class


    lbUtil.calcPoints(Injured, Damage);

    lbInv.lbUtil = lbUtil;

    Injured.AddInventory(lbInv);




    abilityLvl = lbUtil.abilityLvl;

    //if limit break has been reached do the limit break by modifying the pawn.
    if(lbUtil.isLimit)
    {
      ModifyPawn(Injured, abilityLvl);
    }




}//HandleDamage()









/**
   Get the cost of purchasing LimitBreak for param CurrentLevel. <br />
   <i>No specific class or lvl requirments implemented.</i>
*/
static simulated function int Cost(RPGPlayerDataObject Data, int CurrentLevel)
{
   return super.Cost(Data, CurrentLevel);
}



DefaultProperties
{

    AbilityName="Limit break"
    Description="Each map you start with 0 limit points as you play you are given limit points when | a.)You are awarded kill bonuses | b.)Are damaged by the enemy (calculated based on your current health & level)|Cost (per level): 7,14,21"
    StartingCost=7
    CostAddPerLevel=7
    MaxLevel=3

}