//-----------------------------------------------------------
//          LimitBreakUtil                                   <br />
//                                                           <br />
//          Utility Class for working around RPGAbilities
//          static funcitons. Most of the functionality
//          is in this class.                                <br />
//                                                           <br />
//          Author: Continuum                                <br />
//
//-----------------------------------------------------------
class LimitBreakUtil  extends Object config(UT2004RPG);


/*
   04Mar2007
   Variables need to be gone through again... some aren't
   usefull and others have bad descriptions.

*/


/** Length of lvl 1 limit break. <br />
    Higher lvls of limit break may add
    aditional time? */
var config float breakLength;


/** Percentage of pawn lvl for adjusting amount of points based on players current level. */
var config float lvlFactor;

/** Minimum number of limit points needed to reach a limit break. */
var config int minLimitPoints;
/** Maximum number of limit points needed to reach a limit break. */
var config int maxLimitPoints;

/** Percentage for adjusting amount of points based on damage. <br /> not used by default*/
var config float damageFactor;
/** Used with lvlFactor when player has 75% - max health. */
var config float hpFull;
/** Used with lvlFactor when player has 50% - 75% max Health. */
var config float hp50;
/** Used with lvlFactor when player has 15% - 50% max Health. */
var config float hp15;
/** Used with lvlFactor when player has less than 15% max Health. */
var config float hpCritical;




/** Number of points needed for pawns limit break to be reached. */
var float playersLimitBreak;
/** Current number of limit points the player has. */
var float limitPoints;
/** true while players limitPoints == playersLimitBreak && countdown > 0 */
var bool isLimit;
/** The players level. */
var int playerLvl;
/** The players limit break lvl. */
var int limitLvl;
/** Calculated from pawns current (health, max health, matched to hpFull - hpCritical ranges). */
var float healthFactor;
/** Calculated from (lvlFactor, pawns level) & (pawns.Health, healthFactor) & (Damage) */
var float pointFactor;


var int abilityLvl;
/**
  Calculates the healthFactor used in limitPoint calculation.<br />
  <ul>
      <li>@param health Injured.Health</li>
      <li>@param maxHealth Injured.SuperMaxHealth</li>

  </ul>


*/
function calcHealthFactor(float health, float superMaxHealth)
{
   local float percOfSuperMax;
   percOfSuperMax = 1.00;

   percOfSuperMax = health / superMaxHealth;

   if(percOfSuperMax >= (0.75 * superMaxHealth))
   {
      healthFactor = hpFull;//use hpFull when calculating limit points
   }
   else if(percOfSuperMax >= (0.50 * superMaxHealth))
   {
      healthFactor = hp50;//use hp50 when calculating limit points
   }
   else if(percOfSuperMax >= (0.15 * superMaxHealth))
   {
      healthFactor = hp15;//use hp15 when calculating limit points
   }
   else if(percOfSuperMax < (0.15 * superMaxHealth))
   {
      healthFactor = hpCritical;//use hpCritical when calculating limit points
   }
   else
   {
       log("!!WARNING!! LimitBreakUtil.calcHealthFactor() has hit catch all (else) returning 0.01");
       healthFactor = 0.01;//Something probably went wrong, return a number larger than 0 to use when calculating limit points
   }



}//calcHealthFactor()


/**
   Calculates the actuall limitPoints given to the pawn
   from recieving damage.
*/
function calcPoints(Pawn p, int Damage)
{

 local AbilityLimitBreak ab;
 local RPGPlayerManip playerManip;

 abilityLvl = playerManip.getRPGPlayerAbilityLvl(p, ab);//need player lvl
 playerLvl = playerManip.getRPGPlayerLvl(p);

 /*
   (1 to 3) * ((0.15 to 1.00) * Damage) / (playerLvl * lvlFactor))

   example 1
           abilityLvl = 3, healthFactor = 0.50, Damage = 30, playerLvl = 100, lvlFactor = 0.60
           limitPoints =  0.45

 */
 limitPoints = limitPoints + (abilityLvl * ((healthFactor * Damage) / playerLvl));

 if(limitPoints >= playersLimitBreak)
 {
  isLimit = true;
 }

}//calcPoints()


DefaultProperties
{


    limitPoints=0
    breakLength=5
    playersLimitBreak=800
    lvlFactor=0.60
    damageFactor=0.10
    hpFull=0.15
    hp50=0.50
    hp15=0.75
    hpCritical=1.00
    minLimitPoints=100
    maxLimitPoints=2000
}
