//-----------------------------------------------------------
//          RPGPlayerManip                                   <br />
//                                                           <br />
//          Utility Class for manipulating the RPG Players
//          Temporary package untill more utilities are
//          created.                                         <br />
//                                                           <br />
//          Author: Continuum                                <br />
//
//-----------------------------------------------------------
class RPGPlayerManip  extends Object;


/**
   Cycle through pawns inventory and find the RPGPlayerDataObject in it,
   Return the RPGPlayerDataObject.
   <ul>
       <li>@param Pawn The pawn to look in.</li>
   </ul>

   <br />
   <b>Note</b><br />
   <i>The RPGPlayerDataObject that is returned from this method is initialized to
   none so check if it == none before using.</i>
*/
static function RPGPlayerDataObject getRPGPlayerData(Pawn p)
{


 local RPGStatsInv StatsInv;
 local RPGPlayerDataObject rpgPlayer;
 rpgPlayer = none;
 StatsInv = none;


 /*
   If no controller or not a player do not continue.
 */
 if (p.Controller == None || !p.Controller.bIsPlayer)
 {
  return none;
 }//if


 StatsInv = RPGStatsInv(p.FindInventoryType(class'RPGStatsInv'));//Find the RPGStatsInv object in the pawns inventory

 if (StatsInv != None)
 {
    rpgPlayer = StatsInv.DataObject;
 }

 return rpgPlayer;//check for null when calling



}//getRpgPlayerData()


/**
  Returns the level of an RPGPlayer.
  <ul>
      <li>@param p The pawn</li>
  </ul>
*/
static function int getRPGPlayerLvl(Pawn p)
{
       local RPGPlayerDataObject rpgPlayer;
       local int playerLvl;

       playerLvl = 0;
       rpgPlayer = getRPGPlayerData(p);
       if(rpgPlayer == none)
       {
        log("RPGPlayerManip.getRPGPlayerLvl() did not return a RPGPLayerDataObject!");
        return -1;
       }
       else
       {
        playerLvl = rpgPlayer.Level;
        return playerLvl;
       }

}//getRPGPlayerLvl()


/**
   Get the lvl of an ability.<br />
   <ul>
       <li>@param p Pawn wanting their ability lvl</li>
       <li>@param ability The ability that the lvl is needed for</li>
   </ul>
   <br />
   <i>Edit<br />
   No suitable static properties or functions could be used for this so this
   function no longer uses RPGAbility as the 2nd Parameter... RPGAbility needs
   a static name or id field for this to work properly.</i>
*/
static function int getRPGPlayerAbilityLvl(Pawn p, AbilityLimitBreak ability)
{
       local RPGPlayerDataObject rpgPlayer;
       local int abilityLvl;
       local int i;

       abilityLvl = 0;




       getRPGPlayerData(p);

       for(i = 0; i < rpgPlayer.Abilities.length; i++)
       {

       /*
         In the future re-write to be <br />
         if(rpgPlayer.Abilities.static.abilityName == abiliti.abilityName)
       */
        if(rpgPlayer.Abilities[i].class == ability.Class)
        {
           abilityLvl = rpgPlayer.AbilityLevels[i];
        }



       }

       return abilityLvl;

}//getRPGPLayerAbilityLvl()